aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java
diff options
context:
space:
mode:
authorNotAPenguin <michiel.vandeginste@gmail.com>2024-09-02 23:17:17 +0200
committerGitHub <noreply@github.com>2024-09-02 23:17:17 +0200
commit1b820de08a05070909a267e17f033fcf58ac8710 (patch)
tree02831a025986a06b20f87e5bcc69d1e0c639a342 /src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java
parentafd3fd92b6a6ab9ab0d0dc3214e6bc8ff7a86c9b (diff)
downloadGT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.tar.gz
GT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.tar.bz2
GT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.zip
The Great Renaming (#3014)
* move kekztech to a single root dir * move detrav to a single root dir * move gtnh-lanthanides to a single root dir * move tectech and delete some gross reflection in gt++ * remove more reflection inside gt5u * delete more reflection in gt++ * fix imports * move bartworks and bwcrossmod * fix proxies * move galactigreg and ggfab * move gtneioreplugin * try to fix gt++ bee loader * apply the rename rules to BW * apply rename rules to bwcrossmod * apply rename rules to detrav scanner mod * apply rename rules to galacticgreg * apply rename rules to ggfab * apply rename rules to goodgenerator * apply rename rules to gtnh-lanthanides * apply rename rules to gt++ * apply rename rules to kekztech * apply rename rules to kubatech * apply rename rules to tectech * apply rename rules to gt apply the rename rules to gt * fix tt import * fix mui hopefully * fix coremod except intergalactic * rename assline recipe class * fix a class name i stumbled on * rename StructureUtility to GTStructureUtility to prevent conflict with structurelib * temporary rename of GTTooltipDataCache to old name * fix gt client/server proxy names
Diffstat (limited to 'src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java')
-rw-r--r--src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java b/src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java
index e57ebaf5f9..e7253b6ea5 100644
--- a/src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java
+++ b/src/main/java/gtPlusPlus/api/recipe/TGSFrontend.java
@@ -15,14 +15,14 @@ import com.gtnewhorizons.modularui.api.math.Pos2d;
import gregtech.api.recipe.BasicUIPropertiesBuilder;
import gregtech.api.recipe.NEIRecipePropertiesBuilder;
import gregtech.api.recipe.RecipeMapFrontend;
-import gregtech.api.util.GT_Recipe;
+import gregtech.api.util.GTRecipe;
import gregtech.api.util.MethodsReturnNonnullByDefault;
import gregtech.common.gui.modularui.UIHelper;
-import gregtech.nei.GT_NEI_DefaultHandler;
+import gregtech.nei.GTNEIDefaultHandler;
import gregtech.nei.RecipeDisplayInfo;
import gregtech.nei.formatter.INEISpecialInfoFormatter;
-import gtPlusPlus.xmod.gregtech.common.tileentities.machines.multi.production.GregtechMetaTileEntityTreeFarm;
-import gtPlusPlus.xmod.gregtech.common.tileentities.machines.multi.production.GregtechMetaTileEntityTreeFarm.Mode;
+import gtPlusPlus.xmod.gregtech.common.tileentities.machines.multi.production.MTETreeFarm;
+import gtPlusPlus.xmod.gregtech.common.tileentities.machines.multi.production.MTETreeFarm.Mode;
@ParametersAreNonnullByDefault
@MethodsReturnNonnullByDefault
@@ -80,15 +80,15 @@ public class TGSFrontend extends RecipeMapFrontend {
@Override
public List<String> handleNEIItemTooltip(ItemStack stack, List<String> currentTip,
- GT_NEI_DefaultHandler.CachedDefaultRecipe neiCachedRecipe) {
+ GTNEIDefaultHandler.CachedDefaultRecipe neiCachedRecipe) {
/*
* This gets a little complicated, because we want to assign tooltips to inputs/outputs based on which mode
* (saw, shears, etc.) they correspond to. But CachedDefaultRecipe does not retain this information for us. This
* is because some recipes don't output any items for some modes. For example, if a recipe only yields logs and
* leaves, then the outputs of GT_Recipe will be {log, null, leaves}. However, in CachedDefaultRecipe this gets
* condensed to just {log, leaves}, with null values omitted. So to figure out which item came from which mode,
* we need to step through both of these arrays simultaneously and match non-null inputs/outputs in GT_Recipe to
* inputs/outputs in CachedDefaultRecipe.
*/
@@ -99,7 +99,7 @@ public class TGSFrontend extends RecipeMapFrontend {
return currentTip;
}
- GT_Recipe.GT_Recipe_WithAlt recipe = (GT_Recipe.GT_Recipe_WithAlt) neiCachedRecipe.mRecipe;
+ GTRecipe.GTRecipe_WithAlt recipe = (GTRecipe.GTRecipe_WithAlt) neiCachedRecipe.mRecipe;
// Inputs
int slot = 0;
@@ -107,7 +107,7 @@ public class TGSFrontend extends RecipeMapFrontend {
if (mode < recipe.mOreDictAlt.length && recipe.mOreDictAlt[mode] != null) {
// There is a valid input in this mode.
if (slot < neiCachedRecipe.mInputs.size() && stack == neiCachedRecipe.mInputs.get(slot).item) {
- int toolMultiplier = GregtechMetaTileEntityTreeFarm.getToolMultiplier(stack, Mode.values()[mode]);
+ int toolMultiplier = MTETreeFarm.getToolMultiplier(stack, Mode.values()[mode]);
currentTip.add(EnumChatFormatting.YELLOW + tooltipInputs[mode]);
if (toolMultiplier > 0) {
currentTip.add(EnumChatFormatting.YELLOW + tooltipMultiplier + " " + toolMultiplier + "x");
@@ -80,15 +80,15 @@ public class TGSFrontend extends RecipeMapFrontend {
* (saw, shears, etc.) they correspond to. But CachedDefaultRecipe does not retain this information for us. This
* is because some recipes don't output any items for some modes. For example, if a recipe only yields logs and
- * leaves, then the outputs of GT_Recipe will be {log, null, leaves}. However, in CachedDefaultRecipe this gets
+ * leaves, then the outputs of GTRecipe will be {log, null, leaves}. However, in CachedDefaultRecipe this gets
* condensed to just {log, leaves}, with null values omitted. So to figure out which item came from which mode,
@@ -80,15 +80,15 @@ public class TGSFrontend extends RecipeMapFrontend {
* condensed to just {log, leaves}, with null values omitted. So to figure out which item came from which mode,
- * we need to step through both of these arrays simultaneously and match non-null inputs/outputs in GT_Recipe to
+ * we need to step through both of these arrays simultaneously and match non-null inputs/outputs in GTRecipe to
* inputs/outputs in CachedDefaultRecipe.
*/